;************************************************************************
;*																		*
;*	CEREBOT_II.INC	--	General Cerebot II Interface Declarations		*
;*																		*
;************************************************************************
;*	Author:		Gene Apperson											*
;*	Copyright 2007, Digilent Inc.										*
;************************************************************************
;*	Module Description:													*
;*																		*
;*	This header file contains symbol declarations describing ports and	*
;*	pins for access to the on-board i/o devices and interface connector	*
;*	pins on the Cerebot.												*
;*																		*
;************************************************************************
;*	Revision History:													*
;*																		*
;*	06/07/2007(GeneA): created											*
;*																		*
;************************************************************************
;
.ifndef	_CEREBOT_II_INC

.equ	_CEREBOT_II_INC = 1
;
; ---------------------------------------------------------------
;			ATmega64  Internal Declarations
; ---------------------------------------------------------------
;
; These are declarations for useful symbols missing from the
; standard Atmel AVR chip definitions file
;
; Declare bits in the status register
.equ	bnCF	= 0
.equ	bnZF	= 1
.equ	bnNF	= 2
.equ	bnVF	= 3
.equ	bnSF	= 4
.equ	bnHF	= 5
.equ	bnTF	= 6
.equ	bnIF	= 7

; ---------------------------------------------------------------
;				On-Board I/O Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to local LEDs
.equ	prtLed1	= PORTE
.equ	prtLed2 = PORTE
.equ	prtLed3 = PORTE
.equ	prtLed4 = PORTE

.equ	ddrLed1 = DDRE
.equ	ddrLed2 = DDRE
.equ	ddrLed3 = DDRE
.equ	ddrLed4 = DDRE

.equ	bnLed1	= 4
.equ	bnLed2	= 5
.equ	bnLed3	= 6
.equ	bnLed4	= 7
;
; Symbol definitions for the user input jumper, JP5
.equ	prtJP5	= PORTG
.equ	pinJP5	= PING
.equ	ddrJP5	= DDRG
.equ	bnJP5	= 4

; ---------------------------------------------------------------
;				Interface Connector Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to connector JA
.equ	prtJA1	= PORTA
.equ	prtJA2	= PORTA
.equ	prtJA3	= PORTA
.equ	prtJA4	= PORTA
.equ	prtJA7	= PORTA
.equ	prtJA8	= PORTA
.equ	prtJA9	= PORTA
.equ	prtJA10	= PORTA

.equ	pinJA1	= PINA
.equ	pinJA2	= PINA
.equ	pinJA3	= PINA
.equ	pinJA4	= PINA
.equ	pinJA7	= PINA
.equ	pinJA8	= PINA
.equ	pinJA9	= PINA
.equ	pinJA10	= PINA

.equ	ddrJA1	= DDRA
.equ	ddrJA2	= DDRA
.equ	ddrJA3	= DDRA
.equ	ddrJA4	= DDRA
.equ	ddrJA7	= DDRA
.equ	ddrJA8	= DDRA
.equ	ddrJA9	= DDRA
.equ	ddrJA10	= DDRA

.equ	bnJA1	= 0
.equ	bnJA2	= 1
.equ	bnJA3	= 2
.equ	bnJA4	= 3
.equ	bnJA7	= 4
.equ	bnJA8	= 5
.equ	bnJA9	= 6
.equ	bnJA10	= 7
;
; Symbol definitions for access to connector JB
.equ	prtJB1	= PORTC
.equ	prtJB2	= PORTC
.equ	prtJB3	= PORTC
.equ	prtJB4	= PORTC
.equ	prtJB7	= PORTC
.equ	prtJB8	= PORTC
.equ	prtJB9	= PORTC
.equ	prtJB10	= PORTC

.equ	pinJB1	= PINC
.equ	pinJB2	= PINC
.equ	pinJB3	= PINC
.equ	pinJB4	= PINC
.equ	pinJB7	= PINC
.equ	pinJB8	= PINC
.equ	pinJB9	= PINC
.equ	pinJB10	= PINC

.equ	ddrJB1	= DDRC
.equ	ddrJB2	= DDRC
.equ	ddrJB3	= DDRC
.equ	ddrJB4	= DDRC
.equ	ddrJB7	= DDRC
.equ	ddrJB8	= DDRC
.equ	ddrJB9	= DDRC
.equ	ddrJB10	= DDRC

.equ	bnJB1	= 0
.equ	bnJB2	= 1
.equ	bnJB3	= 2
.equ	bnJB4	= 3
.equ	bnJB7	= 4
.equ	bnJB8	= 5
.equ	bnJB9	= 6
.equ	bnJB10	= 7
;
; Symbol definitions for access to connector JC
.equ	prtJC1	= PORTE
.equ	prtJC2	= PORTE
.equ	prtJC3	= PORTE
.equ	prtJC4	= PORTE
.equ	prtJC7	= PORTG
.equ	prtJC8	= PORTG
.equ	prtJC9	= PORTG
.equ	prtJC10	= PORTG

.equ	pinJC1	= PINE
.equ	pinJC2	= PINE
.equ	pinJC3	= PINE
.equ	pinJC4	= PINE
.equ	pinJC7	= PING
.equ	pinJC8	= PING
.equ	pinJC9	= PING
.equ	pinJC10	= PING

.equ	ddrJC1	= DDRE
.equ	ddrJC2	= DDRE
.equ	ddrJC3	= DDRE
.equ	ddrJC4	= DDRE
.equ	ddrJC7	= DDRG
.equ	ddrJC8	= DDRG
.equ	ddrJC9	= DDRG
.equ	ddrJC10	= DDRG

.equ	bnJC1	= 2
.equ	bnJC2	= 3
.equ	bnJC3	= 0
.equ	bnJC4	= 1
.equ	bnJC7	= 0
.equ	bnJC8	= 1
.equ	bnJC9	= 2
.equ	bnJC10	= 3
;
; Symbol definitions for access to connector JD
.equ	prtJD1	= PORTB
.equ	prtJD2	= PORTB
.equ	prtJD3	= PORTB
.equ	prtJD4	= PORTB
.equ	prtJD7	= PORTD
.equ	prtJD8	= PORTD
.equ	prtJD9	= PORTD
.equ	prtJD10	= PORTD

.equ	pinJD1	= PINB
.equ	pinJD2	= PINB
.equ	pinJD3	= PINB
.equ	pinJD4	= PINB
.equ	pinJD7	= PIND
.equ	pinJD8	= PIND
.equ	pinJD9	= PIND
.equ	pinJD10	= PIND

.equ	ddrJD1	= DDRB
.equ	ddrJD2	= DDRB
.equ	ddrJD3	= DDRB
.equ	ddrJD4	= DDRB
.equ	ddrJD7	= DDRD
.equ	ddrJD8	= DDRD
.equ	ddrJD9	= DDRD
.equ	ddrJD10	= DDRD

.equ	bnJD1	= 0
.equ	bnJD2	= 2
.equ	bnJD3	= 3
.equ	bnJD4	= 1
.equ	bnJD7	= 0
.equ	bnJD8	= 1
.equ	bnJD9	= 2
.equ	bnJD10	= 3
;
; Symbol definitions for access to connector JE
.equ	prtJE1	= PORTD
.equ	prtJE2	= PORTB
.equ	prtJE3	= PORTD
.equ	prtJE4	= PORTB

.equ	pinJE1	= PIND
.equ	pinJE2	= PINB
.equ	pinJE3	= PIND
.equ	pinJE4	= PINB

.equ	ddrJE1	= DDRD
.equ	ddrJE2	= DDRB
.equ	ddrJE3	= DDRD
.equ	ddrJE4	= DDRB

.equ	bnJE1	= 6
.equ	bnJE2	= 5
.equ	bnJE3	= 4
.equ	bnJE4	= 6
;
; Symbol definitions for access to connector JF
.equ	prtJF1	= PORTE
.equ	prtJF2	= PORTE
.equ	prtJF3	= PORTE
.equ	prtJF4	= PORTE

.equ	pinJF1	= PINE
.equ	pinJF2	= PINE
.equ	pinJF3	= PINE
.equ	pinJF4	= PINE

.equ	ddrJF1	= DDRE
.equ	ddrJF2	= DDRE
.equ	ddrJF3	= DDRE
.equ	ddrJF4	= DDRE

.equ	bnJF1	= 6
.equ	bnJF2	= 4
.equ	bnJF3	= 7
.equ	bnJF4	= 5
;
; Symbol definitions for access to connector JG
.equ	prtJG1	= PORTD
.equ	prtJG2	= PORTB
.equ	prtJG3	= PORTD
.equ	prtJG4	= PORTB

.equ	pinJG1	= PIND
.equ	pinJG2	= PINB
.equ	pinJG3	= PIND
.equ	pinJG4	= PINB

.equ	ddrJG1	= DDRD
.equ	ddrJG2	= DDRB
.equ	ddrJG3	= DDRD
.equ	ddrJG4	= DDRB

.equ	bnJG1	= 7
.equ	bnJG2	= 4
.equ	bnJG3	= 5
.equ	bnJG4	= 7
;
; Symbol definitions for access to connector JH
.equ	prtJH1	= PORTF
.equ	prtJH2	= PORTF
.equ	prtJH3	= PORTF
.equ	prtJH4	= PORTF
.equ	prtJH7	= PORTF
.equ	prtJH8	= PORTF
.equ	prtJH9	= PORTF
.equ	prtJH10	= PORTF

.equ	pinJH1	= PINF
.equ	pinJH2	= PINF
.equ	pinJH3	= PINF
.equ	pinJH4	= PINF
.equ	pinJH7	= PINF
.equ	pinJH8	= PINF
.equ	pinJH9	= PINF
.equ	pinJH10	= PINF

.equ	ddrJH1	= DDRF
.equ	ddrJH2	= DDRF
.equ	ddrJH3	= DDRF
.equ	ddrJH4	= DDRF
.equ	ddrJH7	= DDRF
.equ	ddrJH8	= DDRF
.equ	ddrJH9	= DDRF
.equ	ddrJH10	= DDRF

.equ	bnJH1	= 0
.equ	bnJH2	= 1
.equ	bnJH3	= 2
.equ	bnJH4	= 3
.equ	bnJH7	= 4
.equ	bnJH8	= 5
.equ	bnJH9	= 6
.equ	bnJH10	= 7

; ---------------------------------------------------------------
;			Symbol Definitions for Servo Connectors
; ---------------------------------------------------------------
;
.equ	prtServo1 = PORTF
.equ	prtServo2 = PORTF
.equ	prtServo3 = PORTF
.equ	prtServo4 = PORTF
.equ	prtServo5 = PORTF
.equ	prtServo6 = PORTF
.equ	prtServo7 = PORTF
.equ	prtServo8 = PORTF

.equ	pinServo1 = PINF
.equ	pinServo2 = PINF
.equ	pinServo3 = PINF
.equ	pinServo4 = PINF
.equ	pinServo5 = PINF
.equ	pinServo6 = PINF
.equ	pinServo7 = PINF
.equ	pinServo8 = PINF

.equ	ddrServo1 = DDRF
.equ	ddrServo2 = DDRF
.equ	ddrServo3 = DDRF
.equ	ddrServo4 = DDRF
.equ	ddrServo5 = DDRF
.equ	ddrServo6 = DDRF
.equ	ddrServo7 = DDRF
.equ	ddrServo8 = DDRF

.equ	bnServo1  = 0
.equ	bnServo2  = 1
.equ	bnServo3  = 2
.equ	bnServo4  = 3
.equ	bnServo5  = 4
.equ	bnServo6  = 5
.equ	bnServo7  = 6
.equ	bnServo8  = 7

; ---------------------------------------------------------------

.endif
;
;************************************************************************
