;************************************************************************
;*																		*
;*	Cerebot_Nano.inc	--	General Interface Declarations				*
;*																		*
;************************************************************************
;*	Author:		Gene Apperson											*
;*	Copyright 2008, Digilent Inc.										*
;************************************************************************
;*	Module Description:													*
;*																		*
;*	This header file contains symbol declarations describing ports and	*
;*	pins for access to the on-board i/o devices and interface connector	*
;*	pins on the Cerebot Nano.											*
;*																		*
;************************************************************************
;*	Revision History:													*
;*																		*
;*	10/15/2008(GeneA): created											*
;*																		*
;************************************************************************
;
.ifndef	_CEREBOT_NANO_INC

.equ	_CEREBOT_NANO_INC = 1
;
; ---------------------------------------------------------------
;			ATmega168  Internal Declarations
; ---------------------------------------------------------------
;
; These are declarations for useful symbols missing from the
; standard Atmel AVR chip definitions file
;
; Declare bits in the status register
.equ	bnCF	= 0
.equ	bnZF	= 1
.equ	bnNF	= 2
.equ	bnVF	= 3
.equ	bnSF	= 4
.equ	bnHF	= 5
.equ	bnTF	= 6
.equ	bnIF	= 7

; ---------------------------------------------------------------
;				On-Board I/O Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to local LEDs
.equ	prtLed1	= PORTD
.equ	prtLed2 = PORTD
.equ	prtLed3	= PORTD
.equ	prtLed4	= PORTD

.equ	ddrLed1 = DDRD
.equ	ddrLed2 = DDRD
.equ	ddrLed3	= DDRD
.equ	ddrLed4	= DDRD

.equ	bnLed1	= 5
.equ	bnLed2	= 3
.equ	bnLed3	= 4
.equ	bnLed4	= 2

; TWI pullups. The NanoCon is set up with software selectable
; pull-up resistors on the TWI signal lines. Set the pins as
; outputs and drive them high to enable the pullups. Set the pins
; as inputs, with internal pull-ups disabled, to disable the
; pull-ups. TWI is an open collector bus. One and only one device
; on the bus should provide the pull-ups.
.equ	prtTwiPen	= PORTB

.equ	ddrTwiPen	= DDRB

.equ	bnTwiPeScl	= 6
.equ	bnTwiPeSda	= 7

; ---------------------------------------------------------------
;				Interface Connector Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to connector JA
.equ	prtJA1	= PORTC
.equ	prtJA2	= PORTC
.equ	prtJA3	= PORTC
.equ	prtJA4	= PORTC
.equ	prtJA7	= PORTD
.equ	prtJA8	= PORTB
.equ	prtJA9	= PORTB
.equ	prtJA10	= PORTD

.equ	pinJA1	= PINC
.equ	pinJA2	= PINC
.equ	pinJA3	= PINC
.equ	pinJA4	= PINC
.equ	pinJA7	= PIND
.equ	pinJA8	= PINB
.equ	pinJA9	= PINB
.equ	pinJA10	= PIND

.equ	ddrJA1	= DDRC
.equ	ddrJA2	= DDRC
.equ	ddrJA3	= DDRC
.equ	ddrJA4	= DDRC
.equ	ddrJA7	= DDRD
.equ	ddrJA8	= DDRB
.equ	ddrJA9	= DDRB
.equ	ddrJA10	= DDRD

.equ	bnJA1	= 0
.equ	bnJA2	= 1
.equ	bnJA3	= 2
.equ	bnJA4	= 3
.equ	bnJA7	= 2
.equ	bnJA8	= 1
.equ	bnJA9	= 0
.equ	bnJA10	= 3
;
; Symbol definitions for access to connector JB
.equ	prtJB1	= PORTC
.equ	prtJB2	= PORTC
.equ	prtJB3	= PORTD
.equ	prtJB4	= PORTD
.equ	prtJB7	= PORTD
.equ	prtJB8	= PORTD
.equ	prtJB9	= PORTD
.equ	prtJB10	= PORTD

.equ	pinJB1	= PINC
.equ	pinJB2	= PINC
.equ	pinJB3	= PIND
.equ	pinJB4	= PIND
.equ	pinJB7	= PIND
.equ	pinJB8	= PIND
.equ	pinJB9	= PIND
.equ	pinJB10	= PIND

.equ	ddrJB1	= DDRC
.equ	ddrJB2	= DDRC
.equ	ddrJB3	= DDRD
.equ	ddrJB4	= DDRD
.equ	ddrJB7	= DDRD
.equ	ddrJB8	= DDRD
.equ	ddrJB9	= DDRD
.equ	ddrJB10	= DDRD

.equ	bnJB1	= 5
.equ	bnJB2	= 4
.equ	bnJB3	= 0
.equ	bnJB4	= 1
.equ	bnJB7	= 4
.equ	bnJB8	= 5
.equ	bnJB9	= 6
.equ	bnJB10	= 7
;
; Symbol definitions for access to the SPI connector, J1

; J1 connector as SPI interface
.equ	prtSpi	= PORTB
.equ	pinSpi	= PINB
.equ	ddrSpi	= DDRB

.equ	bnSpiSS		= 2
.equ	bnSpiMosi	= 3
.equ	bnSpiMiso	= 4
.equ	bnSpiSck	= 5

; J1 as generic digital I/Os
.equ	prtSpi1	= PORTB
.equ	prtSpi2	= PORTB
.equ	prtSpi3	= PORTB
.equ	prtSpi4	= PORTB

.equ	pinSpi1	= PINB
.equ	pinSpi2	= PINB
.equ	pinSpi3	= PINB
.equ	pinSpi4	= PINB

.equ	ddrSpi1	= DDRB
.equ	ddrSpi2	= DDRB
.equ	ddrSpi3	= DDRB
.equ	ddrSpi4	= DDRB

.equ	bnSpi1	= 2
.equ	bnSpi2	= 3
.equ	bnSpi3	= 4
.equ	bnSpi4	= 5

;
; Symbol definitions for access to the TWI/UART connector.
; This is pins 1-4 of connector JB. The pins are defined
; as generic digital I/Os in the JB declarations.
.equ	prtTwi	= PORTC
.equ	pinTwi	= PINC
.equ	ddrTwi	= DDRC

.equ	bnTwiScl	= 5
.equ	bnTwiSda	= 4

.equ	prtUart	= PORTD
.equ	pinUart	= PIND
.equ	ddrUart	= DDRD

.equ	bnUartBxd	= 0
.equ	bnUartTxd	= 1

; ---------------------------------------------------------------

.endif
;
;************************************************************************
