;************************************************************************
;*																		*
;*	CEREBOT_PLUS.INC --	General Cerebot Plus Interface Declarations		*
;*																		*
;************************************************************************
;*	Author:		Gene Apperson											*
;*	Copyright 2007, Digilent Inc.										*
;************************************************************************
;*	Module Description:													*
;*																		*
;*	This header file contains symbol declarations describing ports and	*
;*	pins for access to the on-board i/o devices and interface connector	*
;*	pins on the Cerebot.												*
;*																		*
;************************************************************************
;*	Revision History:													*
;*																		*
;*	08/07/2007(GeneA): created											*
;*																		*
;************************************************************************
;
.ifndef	_CEREBOT_PLUS_INC

.equ	_CEREBOT_PLUS_INC = 1
;
; ---------------------------------------------------------------
;			ATmega64  Internal Declarations
; ---------------------------------------------------------------
;
; These are declarations for useful symbols missing from the
; standard Atmel AVR chip definitions file
;
; Declare bits in the status register
.equ	bnCF	= 0
.equ	bnZF	= 1
.equ	bnNF	= 2
.equ	bnVF	= 3
.equ	bnSF	= 4
.equ	bnHF	= 5
.equ	bnTF	= 6
.equ	bnIF	= 7

; ---------------------------------------------------------------
;				On-Board I/O Declarations
; ---------------------------------------------------------------
;
; Symbol defintions for external memory interface
.equ	prtXmCs		= PORTG
.equ	prtXmBsel	= PORTG

.equ	pinXmCs		= PING
.equ	pinXmBsel	= PING

.equ	ddrXmCs		= DDRG
.equ	ddrXmBsel	= DDRG

.equ	bnXmCs		= 5
.equ	bnXmBsel	= 3

; Symbol definitions for access to local LEDs
.equ	prtLed1	= PORTE
.equ	prtLed2 = PORTE
.equ	prtLed3 = PORTE
.equ	prtLed4 = PORTE

.equ	ddrLed1 = DDRE
.equ	ddrLed2 = DDRE
.equ	ddrLed3 = DDRE
.equ	ddrLed4 = DDRE

.equ	bnLed1	= 4
.equ	bnLed2	= 5
.equ	bnLed3	= 6
.equ	bnLed4	= 7
;
; Symbol definitions for the user input jumper, JP5
.equ	prtJP5	= PORTG
.equ	pinJP5	= PING
.equ	ddrJP5	= DDRG
.equ	bnJP5	= 4

; ---------------------------------------------------------------
;				Interface Connector Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to connector JA
.equ	prtJA1	= PORTA
.equ	prtJA2	= PORTA
.equ	prtJA3	= PORTA
.equ	prtJA4	= PORTA
.equ	prtJA7	= PORTA
.equ	prtJA8	= PORTA
.equ	prtJA9	= PORTA
.equ	prtJA10	= PORTA

.equ	pinJA1	= PINA
.equ	pinJA2	= PINA
.equ	pinJA3	= PINA
.equ	pinJA4	= PINA
.equ	pinJA7	= PINA
.equ	pinJA8	= PINA
.equ	pinJA9	= PINA
.equ	pinJA10	= PINA

.equ	ddrJA1	= DDRA
.equ	ddrJA2	= DDRA
.equ	ddrJA3	= DDRA
.equ	ddrJA4	= DDRA
.equ	ddrJA7	= DDRA
.equ	ddrJA8	= DDRA
.equ	ddrJA9	= DDRA
.equ	ddrJA10	= DDRA

.equ	bnJA1	= 0
.equ	bnJA2	= 1
.equ	bnJA3	= 2
.equ	bnJA4	= 3
.equ	bnJA7	= 4
.equ	bnJA8	= 5
.equ	bnJA9	= 6
.equ	bnJA10	= 7
;
; Symbol definitions for access to connector JB
.equ	prtJB1	= PORTC
.equ	prtJB2	= PORTC
.equ	prtJB3	= PORTC
.equ	prtJB4	= PORTC
.equ	prtJB7	= PORTC
.equ	prtJB8	= PORTC
.equ	prtJB9	= PORTC
.equ	prtJB10	= PORTC

.equ	pinJB1	= PINC
.equ	pinJB2	= PINC
.equ	pinJB3	= PINC
.equ	pinJB4	= PINC
.equ	pinJB7	= PINC
.equ	pinJB8	= PINC
.equ	pinJB9	= PINC
.equ	pinJB10	= PINC

.equ	ddrJB1	= DDRC
.equ	ddrJB2	= DDRC
.equ	ddrJB3	= DDRC
.equ	ddrJB4	= DDRC
.equ	ddrJB7	= DDRC
.equ	ddrJB8	= DDRC
.equ	ddrJB9	= DDRC
.equ	ddrJB10	= DDRC

.equ	bnJB1	= 0
.equ	bnJB2	= 1
.equ	bnJB3	= 2
.equ	bnJB4	= 3
.equ	bnJB7	= 4
.equ	bnJB8	= 5
.equ	bnJB9	= 6
.equ	bnJB10	= 7
;
; Symbol definitions for access to connector JC
.equ	prtJC1	= PORTE
.equ	prtJC2	= PORTE
.equ	prtJC3	= PORTE
.equ	prtJC4	= PORTE
.equ	prtJC7	= PORTG
.equ	prtJC8	= PORTG
.equ	prtJC9	= PORTG
.equ	prtJC10	= PORTG

.equ	pinJC1	= PINE
.equ	pinJC2	= PINE
.equ	pinJC3	= PINE
.equ	pinJC4	= PINE
.equ	pinJC7	= PING
.equ	pinJC8	= PING
.equ	pinJC9	= PING
.equ	pinJC10	= PING

.equ	ddrJC1	= DDRE
.equ	ddrJC2	= DDRE
.equ	ddrJC3	= DDRE
.equ	ddrJC4	= DDRE
.equ	ddrJC7	= DDRG
.equ	ddrJC8	= DDRG
.equ	ddrJC9	= DDRG
.equ	ddrJC10	= DDRG

.equ	bnJC1	= 2
.equ	bnJC2	= 3
.equ	bnJC3	= 0
.equ	bnJC4	= 1
.equ	bnJC7	= 0
.equ	bnJC8	= 1
.equ	bnJC9	= 2
.equ	bnJC10	= 3
;
; Symbol definitions for access to connector JD
.equ	prtJD1	= PORTB
.equ	prtJD2	= PORTB
.equ	prtJD3	= PORTB
.equ	prtJD4	= PORTB
.equ	prtJD7	= PORTD
.equ	prtJD8	= PORTD
.equ	prtJD9	= PORTD
.equ	prtJD10	= PORTD

.equ	pinJD1	= PINB
.equ	pinJD2	= PINB
.equ	pinJD3	= PINB
.equ	pinJD4	= PINB
.equ	pinJD7	= PIND
.equ	pinJD8	= PIND
.equ	pinJD9	= PIND
.equ	pinJD10	= PIND

.equ	ddrJD1	= DDRB
.equ	ddrJD2	= DDRB
.equ	ddrJD3	= DDRB
.equ	ddrJD4	= DDRB
.equ	ddrJD7	= DDRD
.equ	ddrJD8	= DDRD
.equ	ddrJD9	= DDRD
.equ	ddrJD10	= DDRD

.equ	bnJD1	= 0
.equ	bnJD2	= 2
.equ	bnJD3	= 3
.equ	bnJD4	= 1
.equ	bnJD7	= 0
.equ	bnJD8	= 1
.equ	bnJD9	= 2
.equ	bnJD10	= 3
;
; Symbol definitions for access to connector JE
.equ	prtJE1	= PORTD
.equ	prtJE2	= PORTB
.equ	prtJE3	= PORTD
.equ	prtJE4	= PORTB
.equ	prtJE7	= PORTD
.equ	prtJE8	= PORTB
.equ	prtJE9	= PORTD
.equ	prtJE10	= PORTB

.equ	pinJE1	= PIND
.equ	pinJE2	= PINB
.equ	pinJE3	= PIND
.equ	pinJE4	= PINB
.equ	pinJE7	= PIND
.equ	pinJE8	= PINB
.equ	pinJE9	= PIND
.equ	pinJE10	= PINB

.equ	ddrJE1	= DDRD
.equ	ddrJE2	= DDRB
.equ	ddrJE3	= DDRD
.equ	ddrJE4	= DDRB
.equ	ddrJE7	= DDRD
.equ	ddrJE8	= DDRB
.equ	ddrJE9	= DDRD
.equ	ddrJE10	= DDRB

.equ	bnJE1	= 6
.equ	bnJE2	= 5
.equ	bnJE3	= 4
.equ	bnJE4	= 6
.equ	bnJE7	= 7
.equ	bnJE8	= 4
.equ	bnJE9	= 5
.equ	bnJE10	= 7
;
; Symbol definitions for access to connector JF
.equ	prtJF1	= PORTL
.equ	prtJF2	= PORTL
.equ	prtJF3	= PORTL
.equ	prtJF4	= PORTL
.equ	prtJF7	= PORTL
.equ	prtJF8	= PORTL
.equ	prtJF9	= PORTL
.equ	prtJF10	= PORTL

.equ	pinJF1	= PINL
.equ	pinJF2	= PINL
.equ	pinJF3	= PINL
.equ	pinJF4	= PINL
.equ	pinJF7	= PINL
.equ	pinJF8	= PINL
.equ	pinJF9	= PINL
.equ	pinJF10	= PINL

.equ	ddrJF1	= DDRL
.equ	ddrJF2	= DDRL
.equ	ddrJF3	= DDRL
.equ	ddrJF4	= DDRL
.equ	ddrJF7	= DDRL
.equ	ddrJF8	= DDRL
.equ	ddrJF9	= DDRL
.equ	ddrJF10	= DDRL

.equ	bnJF1	= 2
.equ	bnJF2	= 3
.equ	bnJF3	= 1
.equ	bnJF4	= 4
.equ	bnJF7	= 6
.equ	bnJF8	= 5
.equ	bnJF9	= 0
.equ	bnJF10	= 7
;
; Symbol definitions for access to connector JG
.equ	prtJG1	= PORTE
.equ	prtJG2	= PORTE
.equ	prtJG3	= PORTE
.equ	prtJG4	= PORTE

.equ	pinJG1	= PINE
.equ	pinJG2	= PINE
.equ	pinJG3	= PINE
.equ	pinJG4	= PINE

.equ	ddrJG1	= DDRE
.equ	ddrJG2	= DDRE
.equ	ddrJG3	= DDRE
.equ	ddrJG4	= DDRE

.equ	bnJG1	= 6
.equ	bnJG2	= 4
.equ	bnJG3	= 7
.equ	bnJG4	= 5
;
; Symbol definitions for access to connector JH
.equ	prtJH1	= PORTH
.equ	prtJH2	= PORTH
.equ	prtJH3	= PORTH
.equ	prtJH4	= PORTH
.equ	prtJH7	= PORTH
.equ	prtJH8	= PORTH
.equ	prtJH9	= PORTH
.equ	prtJH10	= PORTH

.equ	pinJH1	= PINH
.equ	pinJH2	= PINH
.equ	pinJH3	= PINH
.equ	pinJH4	= PINH
.equ	pinJH7	= PINH
.equ	pinJH8	= PINH
.equ	pinJH9	= PINH
.equ	pinJH10	= PINH

.equ	ddrJH1	= DDRH
.equ	ddrJH2	= DDRH
.equ	ddrJH3	= DDRH
.equ	ddrJH4	= DDRH
.equ	ddrJH7	= DDRH
.equ	ddrJH8	= DDRH
.equ	ddrJH9	= DDRH
.equ	ddrJH10	= DDRH

.equ	bnJH1	= 2
.equ	bnJH2	= 3
.equ	bnJH3	= 0
.equ	bnJH4	= 1
.equ	bnJH7	= 7
.equ	bnJH8	= 4
.equ	bnJH9	= 6
.equ	bnJH10	= 5

;
; Symbol definitions for access to connector JJ
.equ	prtJJ1	= PORTF
.equ	prtJJ2	= PORTF
.equ	prtJJ3	= PORTF
.equ	prtJJ4	= PORTF
.equ	prtJJ7	= PORTF
.equ	prtJJ8	= PORTF
.equ	prtJJ9	= PORTF
.equ	prtJJ10	= PORTF

.equ	pinJJ1	= PINF
.equ	pinJJ2	= PINF
.equ	pinJJ3	= PINF
.equ	pinJJ4	= PINF
.equ	pinJJ7	= PINF
.equ	pinJJ8	= PINF
.equ	pinJJ9	= PINF
.equ	pinJJ10	= PINF

.equ	ddrJJ1	= DDRF
.equ	ddrJJ2	= DDRF
.equ	ddrJJ3	= DDRF
.equ	ddrJJ4	= DDRF
.equ	ddrJJ7	= DDRF
.equ	ddrJJ8	= DDRF
.equ	ddrJJ9	= DDRF
.equ	ddrJJ10	= DDRF

.equ	bnJJ1	= 0
.equ	bnJJ2	= 1
.equ	bnJJ3	= 2
.equ	bnJJ4	= 3
.equ	bnJJ7	= 4
.equ	bnJJ8	= 5
.equ	bnJJ9	= 6
.equ	bnJJ10	= 7

;
; Symbol definitions for access to connector JK
.equ	prtJK1	= PORTK
.equ	prtJK2	= PORTK
.equ	prtJK3	= PORTK
.equ	prtJK4	= PORTK
.equ	prtJK7	= PORTK
.equ	prtJK8	= PORTK
.equ	prtJK9	= PORTK
.equ	prtJK10	= PORTK

.equ	pinJK1	= PINK
.equ	pinJK2	= PINK
.equ	pinJK3	= PINK
.equ	pinJK4	= PINK
.equ	pinJK7	= PINK
.equ	pinJK8	= PINK
.equ	pinJK9	= PINK
.equ	pinJK10	= PINK

.equ	ddrJK1	= DDRK
.equ	ddrJK2	= DDRK
.equ	ddrJK3	= DDRK
.equ	ddrJK4	= DDRK
.equ	ddrJK7	= DDRK
.equ	ddrJK8	= DDRK
.equ	ddrJK9	= DDRK
.equ	ddrJK10	= DDRK

.equ	bnJK1	= 0
.equ	bnJK2	= 1
.equ	bnJK3	= 2
.equ	bnJK4	= 3
.equ	bnJK7	= 4
.equ	bnJK8	= 5
.equ	bnJK9	= 6
.equ	bnJK10	= 7

;
; Symbol definitions for access to connector JL
.equ	prtJL1	= PORTJ
.equ	prtJL2	= PORTJ
.equ	prtJL3	= PORTJ
.equ	prtJL4	= PORTJ
.equ	prtJL7	= PORTJ
.equ	prtJL8	= PORTJ
.equ	prtJL9	= PORTJ
.equ	prtJL10	= PORTJ

.equ	pinJL1	= PINJ
.equ	pinJL2	= PINJ
.equ	pinJL3	= PINJ
.equ	pinJL4	= PINJ
.equ	pinJL7	= PINJ
.equ	pinJL8	= PINJ
.equ	pinJL9	= PINJ
.equ	pinJL10	= PINJ

.equ	ddrJL1	= DDRJ
.equ	ddrJL2	= DDRJ
.equ	ddrJL3	= DDRJ
.equ	ddrJL4	= DDRJ
.equ	ddrJL7	= DDRJ
.equ	ddrJL8	= DDRJ
.equ	ddrJL9	= DDRJ
.equ	ddrJL10	= DDRJ

.equ	bnJL1	= 2
.equ	bnJL2	= 3
.equ	bnJL3	= 0
.equ	bnJL4	= 1
.equ	bnJL7	= 4
.equ	bnJL8	= 5
.equ	bnJL9	= 6
.equ	bnJL10	= 7

; ---------------------------------------------------------------
;			Symbol Definitions for Servo Connectors
; ---------------------------------------------------------------
;
.equ	prtServo1 = PORTF
.equ	prtServo2 = PORTF
.equ	prtServo3 = PORTF
.equ	prtServo4 = PORTF
.equ	prtServo5 = PORTF
.equ	prtServo6 = PORTF
.equ	prtServo7 = PORTF
.equ	prtServo8 = PORTF

.equ	pinServo1 = PINF
.equ	pinServo2 = PINF
.equ	pinServo3 = PINF
.equ	pinServo4 = PINF
.equ	pinServo5 = PINF
.equ	pinServo6 = PINF
.equ	pinServo7 = PINF
.equ	pinServo8 = PINF

.equ	ddrServo1 = DDRF
.equ	ddrServo2 = DDRF
.equ	ddrServo3 = DDRF
.equ	ddrServo4 = DDRF
.equ	ddrServo5 = DDRF
.equ	ddrServo6 = DDRF
.equ	ddrServo7 = DDRF
.equ	ddrServo8 = DDRF

.equ	bnServo1  = 0
.equ	bnServo2  = 1
.equ	bnServo3  = 2
.equ	bnServo4  = 3
.equ	bnServo5  = 4
.equ	bnServo6  = 5
.equ	bnServo7  = 6
.equ	bnServo8  = 7

; ---------------------------------------------------------------

.endif
;
;************************************************************************
