;************************************************************************
;*																		*
;*	MiniCon.inc	--	General MiniCon Interface Declarations				*
;*																		*
;************************************************************************
;*	Author:		Gene Apperson											*
;*	Copyright 2005, Digilent Inc.										*
;************************************************************************
;*	Module Description:													*
;*																		*
;*	This header file contains symbol declarations describing ports and	*
;*	pins for access to the on-board i/o devices and interface connector	*
;*	pins on the Cerebot.												*
;*																		*
;************************************************************************
;*	Revision History:													*
;*																		*
;*	05/31/2005(GeneA): created											*
;*																		*
;************************************************************************
;
.ifndef	_MINICON_INC

.equ	_MINICON_INC = 1
;
; ---------------------------------------------------------------
;			ATmega168  Internal Declarations
; ---------------------------------------------------------------
;
; These are declarations for useful symbols missing from the
; standard Atmel AVR chip definitions file
;
; Declare bits in the status register
.equ	bnCF	= 0
.equ	bnZF	= 1
.equ	bnNF	= 2
.equ	bnVF	= 3
.equ	bnSF	= 4
.equ	bnHF	= 5
.equ	bnTF	= 6
.equ	bnIF	= 7

; ---------------------------------------------------------------
;				On-Board I/O Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to local LEDs
.equ	prtLed	= PORTD		;port for all LEDs
.equ	prtLed1	= PORTD
.equ	prtLed2 = PORTD
.equ	prtLed3 = PORTD
.equ	prtLed4 = PORTD

.equ	ddrLed	= DDRD		;ddr for all LEDs
.equ	ddrLed1 = DDRD
.equ	ddrLed2 = DDRD
.equ	ddrLed3 = DDRD
.equ	ddrLed4 = DDRD

.equ	mskLed	= 0xF0		;LEDs are on the high order bits
.equ	bnLed1	= 4
.equ	bnLed2	= 5
.equ	bnLed3	= 6
.equ	bnLed4	= 7

; Symbol definitions for mode select jumpers.
; Jumpers JP5 and JP6 are connected to digital inputs.
.equ	prtJP5	= PORTB
.equ	prtJP6	= PORTB

.equ	pinJP5	= PINB
.equ	pinJP6	= PINB

.equ	ddrJP5	= DDRB
.equ	ddrJP6	= DDRB

.equ	bnJP5	= 6
.equ	bnJP6	= 7

; Jumpers JP7 and JP8 are connected via a resistor divider network
; to analog input ADC6. The following voltages will be present at
; the ADC6 input:
;		No Jumper		VCC (3.3V)
;		JP7 Loaded		2*VCC/3 (2.2V)
;		JP8 Loaded		VCC/3 (1.1V)
;		Both Loaded		2*VCC/3 (2.2V)
;
; The ADC7 input can be used to monitor the unregulated power
; supply voltage. For battery powered operation, this can be used
; to monitor battery voltage. This pin is connected to a VU/4
; voltage divider. This allows reading external supply voltages up
; to 12V.
;
; ---------------------------------------------------------------
;				Interface Connector Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to connector JA
.equ	prtJA1	= PORTD
.equ	prtJA2	= PORTD
.equ	prtJA3	= PORTD
.equ	prtJA4	= PORTD

.equ	pinJA1	= PIND
.equ	pinJA2	= PIND
.equ	pinJA3	= PIND
.equ	pinJA4	= PIND

.equ	ddrJA1	= DDRD
.equ	ddrJA2	= DDRD
.equ	ddrJA3	= DDRD
.equ	ddrJA4	= DDRD

.equ	bnJA1	= 4
.equ	bnJA2	= 5
.equ	bnJA3	= 6
.equ	bnJA4	= 7
;
; Symbol definitions for access to connector JB
.equ	prtJB1	= PORTD
.equ	prtJB2	= PORTB
.equ	prtJB3	= PORTB
.equ	prtJB4	= PORTD

.equ	pinJB1	= PIND
.equ	pinJB2	= PINB
.equ	pinJB3	= PINB
.equ	pinJB4	= PIND

.equ	ddrJB1	= DDRD
.equ	ddrJB2	= DDRB
.equ	ddrJB3	= DDRB
.equ	ddrJB4	= DDRD

.equ	bnJB1	= 2
.equ	bnJB2	= 1
.equ	bnJB3	= 0
.equ	bnJB4	= 3
;
; Symbol definitions for access to connector JC
.equ	prtJC1	= PORTC
.equ	prtJC2	= PORTC
.equ	prtJC3	= PORTC
.equ	prtJC4	= PORTC

.equ	pinJC1	= PINC
.equ	pinJC2	= PINC
.equ	pinJC3	= PINC
.equ	pinJC4	= PINC

.equ	ddrJC1	= DDRC
.equ	ddrJC2	= DDRC
.equ	ddrJC3	= DDRC
.equ	ddrJC4	= DDRC

.equ	bnJC1	= 0
.equ	bnJC2	= 1
.equ	bnJC3	= 2
.equ	bnJC4	= 3
;
; Symbol definitions for access to the SPI connector
.equ	prtSpi	= PORTB
.equ	pinSpi	= PINB
.equ	ddrSpi	= DDRB

.equ	bnSpiSS		= 2
.equ	bnSpiMosi	= 3
.equ	bnSpiMiso	= 4
.equ	bnSpiSck	= 5

.equ	prtSpi1	= PORTB
.equ	prtSpi2	= PORTB
.equ	prtSpi3	= PORTB
.equ	prtSpi4	= PORTB

.equ	pinSpi1	= PINB
.equ	pinSpi2	= PINB
.equ	pinSpi3	= PINB
.equ	pinSpi4	= PINB

.equ	ddrSpi1	= DDRB
.equ	ddrSpi2	= DDRB
.equ	ddrSpi3	= DDRB
.equ	ddrSpi4	= DDRB

.equ	bnSpi1	= 2
.equ	bnSpi2	= 3
.equ	bnSpi3	= 4
.equ	bnSpi4	= 5

;
; Symbol definitions for access to the TWI/UART connector
.equ	prtTwi	= PORTC
.equ	pinTwi	= PINC
.equ	ddrTwi	= DDRC

.equ	bnTwiScl	= 5
.equ	bnTwiSda	= 4

.equ	prtUart	= PORTD
.equ	pinUart	= PIND
.equ	ddrUart	= DDRD

.equ	bnUartBxd	= 0
.equ	bnUartTxd	= 1


.equ	prtTwi1	= PORTC
.equ	prtTwi2	= PORTC
.equ	prtTwi3	= PORTD
.equ	prtTwi4	= PORTD

.equ	pinTwi1	= PINC
.equ	pinTwi2	= PINC
.equ	pinTwi3	= PIND
.equ	pinTwi4	= PIND

.equ	ddrTwi1	= DDRC
.equ	ddrTwi2	= DDRC
.equ	ddrTwi3	= DDRD
.equ	ddrTwi4	= DDRD

.equ	bnTwi1	= 5
.equ	bnTwi2	= 4
.equ	bnTwi3	= 0
.equ	bnTwi4	= 1

; ---------------------------------------------------------------

.endif
;
;************************************************************************
