;************************************************************************
;*																		*
;*	NanoCon.inc	--	General NanoCon Interface Declarations				*
;*																		*
;************************************************************************
;*	Author:		Gene Apperson											*
;*	Copyright 2005, 2006, Digilent Inc.									*
;************************************************************************
;*	Module Description:													*
;*																		*
;*	This header file contains symbol declarations describing ports and	*
;*	pins for access to the on-board i/o devices and interface connector	*
;*	pins on the NanoCon.												*
;*																		*
;************************************************************************
;*	Revision History:													*
;*																		*
;*	08/23/2005(GeneA): created											*
;*	03/30/2006(GeneA): updated for Rev B board							*
;*																		*
;************************************************************************
;
.ifndef	_NANOCON_INC

.equ	_NANOCON_INC = 1
;
; ---------------------------------------------------------------
;			ATmega168  Internal Declarations
; ---------------------------------------------------------------
;
; These are declarations for useful symbols missing from the
; standard Atmel AVR chip definitions file
;
; Declare bits in the status register
.equ	bnCF	= 0
.equ	bnZF	= 1
.equ	bnNF	= 2
.equ	bnVF	= 3
.equ	bnSF	= 4
.equ	bnHF	= 5
.equ	bnTF	= 6
.equ	bnIF	= 7

; ---------------------------------------------------------------
;				On-Board I/O Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to local LEDs
.equ	prtLed1	= PORTD
.equ	prtLed2 = PORTD
.equ	prtLed3	= PORTD
.equ	prtLed4	= PORTD

.equ	ddrLed1 = DDRD
.equ	ddrLed2 = DDRD
.equ	ddrLed3	= DDRD
.equ	ddrLed4	= DDRD

.equ	bnLed1	= 4
.equ	bnLed2	= 5
.equ	bnLed3	= 6
.equ	bnLed4	= 7

; TWI pullups. The NanoCon is set up with software selectable
; pull-up resistors on the TWI signal lines. Set the pins as
; outputs and drive them high to enable the pullups. Set the pins
; as inputs, with internal pull-ups disabled, to disable the
; pull-ups. TWI is an open collector bus. One and only one device
; on the bus should provide the pull-ups.
.equ	prtTwiPen	= PORTB

.equ	ddrTwiPen	= DDRB

.equ	bnTwiPeScl	= 6
.equ	bnTwiPeSda	= 7

; ---------------------------------------------------------------
;				Interface Connector Declarations
; ---------------------------------------------------------------
;
; Symbol definitions for access to connector JA
.equ	prtJA1	= PORTC
.equ	prtJA2	= PORTC
.equ	prtJA3	= PORTD
.equ	prtJA4	= PORTD

.equ	pinJA1	= PINC
.equ	pinJA2	= PINC
.equ	pinJA3	= PIND
.equ	pinJA4	= PIND

.equ	ddrJA1	= DDRC
.equ	ddrJA2	= DDRC
.equ	ddrJA3	= DDRD
.equ	ddrJA4	= DDRD

.equ	bnJA1	= 5
.equ	bnJA2	= 4
.equ	bnJA3	= 0
.equ	bnJA4	= 1
;
; Symbol definitions for access to connector JB
.equ	prtJB1	= PORTC
.equ	prtJB2	= PORTC
.equ	prtJB3	= PORTC
.equ	prtJB4	= PORTC

.equ	pinJB1	= PINC
.equ	pinJB2	= PINC
.equ	pinJB3	= PINC
.equ	pinJB4	= PINC

.equ	ddrJB1	= DDRC
.equ	ddrJB2	= DDRC
.equ	ddrJB3	= DDRC
.equ	ddrJB4	= DDRC

.equ	bnJB1	= 0
.equ	bnJB2	= 1
.equ	bnJB3	= 2
.equ	bnJB4	= 3
;
; Symbol definitions for access to connector JC
.equ	prtJC1	= PORTD
.equ	prtJC2	= PORTB
.equ	prtJC3	= PORTB
.equ	prtJC4	= PORTD

.equ	pinJC1	= PIND
.equ	pinJC2	= PINB
.equ	pinJC3	= PINB
.equ	pinJC4	= PIND

.equ	ddrJC1	= DDRD
.equ	ddrJC2	= DDRB
.equ	ddrJC3	= DDRB
.equ	ddrJC4	= DDRD

.equ	bnJC1	= 2
.equ	bnJC2	= 1
.equ	bnJC3	= 0
.equ	bnJC4	= 3
;
; Symbol definitions for access to the SPI connector, J1

; J1 connector as SPI interface
.equ	prtSpi	= PORTB
.equ	pinSpi	= PINB
.equ	ddrSpi	= DDRB

.equ	bnSpiSS		= 2
.equ	bnSpiMosi	= 3
.equ	bnSpiMiso	= 4
.equ	bnSpiSck	= 5

; J1 as generic digital I/Os
.equ	prtSpi1	= PORTB
.equ	prtSpi2	= PORTB
.equ	prtSpi3	= PORTB
.equ	prtSpi4	= PORTB

.equ	pinSpi1	= PINB
.equ	pinSpi2	= PINB
.equ	pinSpi3	= PINB
.equ	pinSpi4	= PINB

.equ	ddrSpi1	= DDRB
.equ	ddrSpi2	= DDRB
.equ	ddrSpi3	= DDRB
.equ	ddrSpi4	= DDRB

.equ	bnSpi1	= 2
.equ	bnSpi2	= 3
.equ	bnSpi3	= 4
.equ	bnSpi4	= 5

;
; Symbol definitions for access to the TWI/UART connector.
; This connector is JA. The pins are defined as generic
; digital I/Os in the JA declarations.
.equ	prtTwi	= PORTC
.equ	pinTwi	= PINC
.equ	ddrTwi	= DDRC

.equ	bnTwiScl	= 5
.equ	bnTwiSda	= 4

.equ	prtUart	= PORTD
.equ	pinUart	= PIND
.equ	ddrUart	= DDRD

.equ	bnUartBxd	= 0
.equ	bnUartTxd	= 1

; ---------------------------------------------------------------

.endif
;
;************************************************************************
